active.data.translate.format

A format is a function [realm] => formatter, which should return nil for unsupported realms.

This namespace contains utilities to create and use such functions.

A format is a function [realm] => formatter, which should return nil for unsupported realms.

This namespace contains utilities to create and use such functions.
raw docstring

active.data.translate.formatter

A formatter is a function [resolve] => translator, which create a translator, potentially based on other translators for a realm returned by the resolve function.

This namespace contains a collection of some standard formatters and utilities to build others.

A formatter is a function [resolve] => translator, which create a translator,
potentially based on other translators for a realm returned by the resolve function.

This namespace contains a collection of some standard formatters and utilities to build others.
raw docstring

active.data.translate.translator

Translators represent the core functionality of translating between internal and external representations of values.

Note that in general, translators should validate the external values, throwing format-error for invalid values, but should assume that internal values are valid, using [[active.data.realm.attach]] so add optional validation.

Translators represent the core functionality of translating between
internal and external representations of values.

Note that in general, translators should validate the external
values, throwing [[format-error]] for invalid values, but should assume
that internal values are valid, using [[active.data.realm.attach]] so add optional validation.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries