(external-realm realm format)Returns the realm of the external values for the given internal realm, as defined by the given format.
May throw unsupported-exn?.
Returns the realm of the external values for the given internal realm, as defined by the given format. May throw [[unsupported-exn?]].
(from-extern realm format)Returns a unary function that translates values from their external to their internal represenation, as defined by the given format.
May throw unsupported-exn?.
The returned function may throw format-error?.
Returns a unary function that translates values from their external to their internal represenation, as defined by the given format. May throw [[unsupported-exn?]]. The returned function may throw [[format-error?]].
(to-extern realm format)Returns a unary function that translates values from their internal to their external represenation, as defined by the given format.
May throw unsupported-exn?.
Returns a unary function that translates values from their internal to their external represenation, as defined by the given format. May throw [[unsupported-exn?]].
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |