active.data.translate.format

A format is a function [realm] => formatter, which should return nil for unsupported realms.

This namespace contains utilities to create and use such functions.

A format is a function [realm] => formatter, which should return nil for unsupported realms.

This namespace contains utilities to create and use such functions.
raw docstring

combine-formatsclj/s

(combine-formats & formats)

Combines multiple formats into one. Earlier formatters for a realm take precedence over later ones.

Combines multiple formats into one. Earlier formatters for a realm take precedence over later ones.
raw docstring

concat-formatsclj/s

(concat-formats & formats)

Concatenate the given formats, ie. translate a value through all of the given formats, left to right for 'to external', and right to left for 'from external'.

Concatenate the given formats, ie. translate a value through all of
the given formats, left to right for 'to external', and right to left
for 'from external'.
raw docstring

emptyclj/s

The empty format that supports nothing.

The empty format that supports nothing.
raw docstring

get-translatorclj/s

(get-translator format realm)

Resolves the translator for the given realm in the given format, or throws unsupported-exn.

Resolves the translator for the given realm in the given format, or throws [[unsupported-exn]].
raw docstring

identityclj/s

A format that keeps all values as they are.

Note that this still resolves any nested realms, so if you combine this with a format that for example translates integers, you get sequences of integers for free.

A format that keeps all values as they are.

Note that this still resolves any nested realms, so if you combine this with a format that for example translates integers, you get sequences of integers for free.
raw docstring

unsupported-exnclj/s

(unsupported-exn realm)

unsupported-exn?clj/s

(unsupported-exn? e)

cljdoc builds & hosts documentation for Clojure/Script libraries