Translators represent the core functionality of translating between internal and external representations of values.
Note that in general, translators should validate the external
values, throwing format-error for invalid values, but should assume
that internal values are valid, using [[active.data.realm.attach]] so add optional validation.
Translators represent the core functionality of translating between internal and external representations of values. Note that in general, translators should validate the external values, throwing [[format-error]] for invalid values, but should assume that internal values are valid, using [[active.data.realm.attach]] so add optional validation.
(add-error-path* position f & args)(concat translator & translators)Concatenates the given translators into one. The translators are applied 'from extern' right to left, and 'to extern' left to right.
Concatenates the given translators into one. The translators are applied 'from extern' right to left, and 'to extern' left to right.
(external-realm Translator)(external-realm Translator value)(format-error problem irritant)(format-error problem irritant location)Returns an exception given a problem description and the problematic value.
Implicitly used the current error location (see with-error-location and [[add-error-path]], unless given explicitly.
Returns an exception given a problem description and the problematic value. Implicitly used the current error location (see [[with-error-location]] and [[add-error-path]], unless given explicitly.
(format-error? e)(from-extern Translator)(from-extern Translator value)(set-error-location* location f & args)(to-extern Translator)(to-extern Translator value)(translator intern-from-extern intern-to-extern external-value-realm)(with-error-location location & body)(with-error-path position & body)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |