active.data.translate.core


external-realmclj/s

(external-realm realm format)

Returns the realm of the external values for the given internal realm, as defined by the given format. May throw unsupported-exn?.

Returns the realm of the external values for the given internal realm, as defined by the given format.
May throw [[unsupported-exn?]].
raw docstring

format-error?clj/s


from-externclj/s

(from-extern realm format)

Returns a unary function that translates values from their external to their internal represenation, as defined by the given format. May throw unsupported-exn?. The returned function may throw format-error?.

Returns a unary function that translates values from their external to their internal represenation, as defined by the given format.
May throw [[unsupported-exn?]].
The returned function may throw [[format-error?]].
raw docstring

to-externclj/s

(to-extern realm format)

Returns a unary function that translates values from their internal to their external represenation, as defined by the given format. May throw unsupported-exn?.

Returns a unary function that translates values from their internal to their external represenation, as defined by the given format.
May throw [[unsupported-exn?]].
raw docstring

unsupported-exn?clj/s

cljdoc builds & hosts documentation for Clojure/Script libraries