active.data.translate.translator

Translators represent the core functionality of translating between internal and external representations of values.

Note that in general, translators should validate the external values, throwing format-error for invalid values, but should assume that internal values are valid, using [[active.data.realm.attach]] so add optional validation.

Translators represent the core functionality of translating between
internal and external representations of values.

Note that in general, translators should validate the external
values, throwing [[format-error]] for invalid values, but should assume
that internal values are valid, using [[active.data.realm.attach]] so add optional validation.
raw docstring

add-error-path*clj/s

(add-error-path* position f & args)

concatclj/s

(concat translator & translators)

Concatenates the given translators into one. The translators are applied 'from extern' right to left, and 'to extern' left to right.

Concatenates the given translators into one. The translators are applied 'from
extern' right to left, and 'to extern' left to right.
raw docstring

external-realmclj/s

(external-realm Translator)
(external-realm Translator value)

format-errorclj/s

(format-error problem irritant)
(format-error problem irritant location)

Returns an exception given a problem description and the problematic value.

Implicitly used the current error location (see with-error-location and [[add-error-path]], unless given explicitly.

Returns an exception given a problem description and the problematic value.

Implicitly used the current error location (see [[with-error-location]] and [[add-error-path]], unless given explicitly.
raw docstring

format-error?clj/s

(format-error? e)

from-externclj/s

(from-extern Translator)
(from-extern Translator value)

set-error-location*clj/s

(set-error-location* location f & args)

to-externclj/s

(to-extern Translator)
(to-extern Translator value)

translatorclj/s

(translator intern-from-extern intern-to-extern external-value-realm)

Translatorclj/s


with-error-locationclj/smacro

(with-error-location location & body)

with-error-pathclj/smacro

(with-error-path position & body)

cljdoc builds & hosts documentation for Clojure/Script libraries